@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -44,7 +44,7 @@ class FTextStream;
 /** Class representing the data associated with a \#include statement. */
 struct IncludeInfo
 {
-  IncludeInfo() { fileDef=0; local=FALSE; indirect=FALSE; }
+  IncludeInfo() : fileDef(0), local(FALSE), imported(FALSE), indirect(FALSE) {}
   ~IncludeInfo() {}
   FileDef *fileDef;
   QCString includeName;
